@@ -16,10 +16,13 @@ from braket.pennylane_plugin.braket_device import (  # noqa: F401
     BraketLocalQubitDevice,
 )
 from braket.pennylane_plugin.ops import (  # noqa: F401
+    MS,
     PSWAP,
     CPhaseShift00,
     CPhaseShift01,
     CPhaseShift10,
+    GPi,
+    GPi2,
 )
 
 from ._version import __version__  # noqa: F401
